 /*
  * Copyright (C), 2018-2021
  * Project: starter
  * FileName: XVueDateEditor
  * Author:   Louis
  * Date:     2021/11/8 11:46
  */
 package com.fr.plugin.hrjf.creator;

 import com.fanruan.api.design.DesignKit;
 import com.fr.design.designer.creator.CRPropertyDescriptor;
 import com.fr.design.designer.creator.XDirectWriteEditor;
 import com.fr.design.designer.creator.XLayoutContainer;
 import com.fr.design.designer.creator.XWScaleLayout;
 import com.fr.design.form.util.XCreatorConstants;
 import com.fr.design.gui.itextfield.UITextField;
 import com.fr.design.layout.FRGUIPaneFactory;
 import com.fr.design.mainframe.widget.editors.DateFormatEditor;
 import com.fr.design.mainframe.widget.editors.WidgetValueEditor;
 import com.fr.form.ui.WidgetValue;
 import com.fr.form.ui.concept.data.ValueInitializer;
 import com.fr.general.DateUtils;
 import com.fr.plugin.hrjf.editors.ConfigurationItemEditor;
 import com.fr.plugin.hrjf.editors.FirstDayOfWeekEditor;
 import com.fr.plugin.hrjf.editors.ReturnTypeEditor;
 import com.fr.plugin.hrjf.editors.ShowDateEditor;
 import com.fr.plugin.hrjf.widget.VueDateEditor;
 import com.fr.stable.ArrayUtils;
 import com.fr.stable.StringUtils;
 import com.fr.stable.core.PropertyChangeAdapter;

 import javax.swing.*;
 import java.awt.*;
 import java.beans.IntrospectionException;
 import java.util.Date;

 /**
  * <Function Description><br>
  * <XVueDateEditor>
  *
  * @author fr.open
  * @since 1.0.0
  */
 public class XVueDateEditor extends XDirectWriteEditor {
     public static final String SHOW_DATE = "showDate";
     public static final String FIRST_DAY_OF_WEEK = "firstDayOfWeek";
     public static final String CONFIGURATION_ITEM = "configurationItem";
     public static final String DATE_FORMAT = "dateFormat";
     public static final String RETURN_FORMAT = "returnFormat";
     public static final String RETURN_TYPE = "returnType";
     public static final String DATE_SEPARATOR = "dateSeparator";
     private UITextField textField;
     private LimpidButton btn;

     public XVueDateEditor(VueDateEditor dateEditor, Dimension dimension) {
         super(dateEditor, dimension);
     }

     /**
      * 控件的属性列表
      *
      * @return 此控件所用的属性列表
      * @throws IntrospectionException 异常
      */
     @Override
     public CRPropertyDescriptor[] supportedDescriptor() throws IntrospectionException {
         CRPropertyDescriptor widgetValueCRP = new CRPropertyDescriptor("widgetValue", this.data.getClass())
                 .setI18NName(DesignKit.i18nText("Fine-Design_Form_Widget_Value"))
                 .setEditorClass(WidgetValueEditor.class)
                 .putKeyValue(XCreatorConstants.PROPERTY_CATEGORY, "Fine-Design_Basic_Advanced")
                 .setPropertyChangeListener(new PropertyChangeAdapter() {
                     @Override
                     public void propertyChange() {
                         initFieldText();
                     }
                 });
//         CRPropertyDescriptor formatTextCRP = new CRPropertyDescriptor("formatText", this.data.getClass())
//                 .setI18NName(DesignKit.i18nText("Fine-Design_Report_Engine_Format"))
//                 .setEditorClass(formatClass()).setRendererClass(DateCellRenderer.class)
//                 .putKeyValue(XCreatorConstants.PROPERTY_CATEGORY, "Fine-Design_Basic_Advanced");
         // 日期格式
         CRPropertyDescriptor dateFormatAttr = new CRPropertyDescriptor(DATE_FORMAT, this.data.getClass())
//                 .setEditorClass(VueDateFormatEditor.class)
                 .setEditorClass(com.fr.plugin.hrjf.editors.DateFormatEditor.class)
                 .setI18NName(DesignKit.i18nText("Plugin-hrjf-Date_Format"))
                 .putKeyValue(XCreatorConstants.PROPERTY_CATEGORY, "Fine-Design_Basic_Advanced");
         // 显示日期格式
         CRPropertyDescriptor showDateCRP = new CRPropertyDescriptor(SHOW_DATE, this.data.getClass())
                 .setEditorClass(ShowDateEditor.class)
                 .setI18NName(DesignKit.i18nText("Plugin-hrjf-Design_Form_Show_Date"))
                 .putKeyValue(XCreatorConstants.PROPERTY_CATEGORY, "Fine-Design_Basic_Advanced");
         // 返回格式
         CRPropertyDescriptor returnFormatCRP = new CRPropertyDescriptor(RETURN_FORMAT, this.data.getClass())
                 .setEditorClass(ShowDateEditor.class)
                 .setI18NName(DesignKit.i18nText("Plugin-hrjf-Design_Form_Return_Format"))
                 .putKeyValue(XCreatorConstants.PROPERTY_CATEGORY, "Fine-Design_Basic_Advanced");
         // 周起始日
         CRPropertyDescriptor firstDayOfWeekAttr = new CRPropertyDescriptor(FIRST_DAY_OF_WEEK, this.data.getClass())
                 .setEditorClass(FirstDayOfWeekEditor.class)
                 .setI18NName(DesignKit.i18nText("Plugin-hrjf-Design_Form_Week_Start_Date"))
                 .putKeyValue(XCreatorConstants.PROPERTY_CATEGORY, "Fine-Design_Basic_Advanced");
         // 返回类型
         CRPropertyDescriptor returnTypeAttr = new CRPropertyDescriptor(RETURN_TYPE, this.data.getClass())
                 .setEditorClass(ReturnTypeEditor.class)
                 .setI18NName(DesignKit.i18nText("Plugin-hrjf-Design_Form_Return_Type"))
                 .putKeyValue(XCreatorConstants.PROPERTY_CATEGORY, "Fine-Design_Basic_Advanced");
         // 数组拼接符
         CRPropertyDescriptor dateSeparatorCRP = new CRPropertyDescriptor(DATE_SEPARATOR, this.data.getClass()).setI18NName(
                 DesignKit.i18nText("Plugin-hrjf-Design_Form_Date_Separator")).putKeyValue(XCreatorConstants.PROPERTY_CATEGORY,
                 "Fine-Design_Basic_Advanced");
         // 配置项
         CRPropertyDescriptor configurationItemCRP = new CRPropertyDescriptor(CONFIGURATION_ITEM, this.data.getClass())
                 .setEditorClass(ConfigurationItemEditor.class)
                 .setI18NName(DesignKit.i18nText("Plugin-hrjf-Design_Form_Configuration_Item"))
                 .putKeyValue(XCreatorConstants.PROPERTY_CATEGORY, "Fine-Design_Basic_Advanced");

         CRPropertyDescriptor[] crp = new CRPropertyDescriptor[]{widgetValueCRP, dateFormatAttr, showDateCRP, returnFormatCRP,
                 firstDayOfWeekAttr, returnTypeAttr, dateSeparatorCRP, configurationItemCRP};
         return ArrayUtils.addAll(super.supportedDescriptor(), crp);
     }

     protected Class formatClass() {
         return DateFormatEditor.class;
     }

     private void initFieldText() {
         VueDateEditor dateEditor = (VueDateEditor) data;
         if (dateEditor.getWidgetValue() != null) {
             ValueInitializer widgetValue = dateEditor.getWidgetValue();
             //控件值.toString
             String valueStr = widgetValue.toString();
             //控件值
             Object value = widgetValue.getValue();
             //格式
             String format = dateEditor.getFormatText();

             if (value instanceof Date) {
                 valueStr = DateUtils.getDate2Str(format, (Date) value);
             }

             //日期控件默认值
             if (StringUtils.isEmpty(valueStr)) {
                 valueStr = DateUtils.getDate2Str(format, new Date());
                 dateEditor.setWidgetValue(new WidgetValue(new Date()));
             }
             textField.setText(valueStr);
         }
     }

     @Override
     protected void initXCreatorProperties() {
         super.initXCreatorProperties();
         initFieldText();
     }

     @Override
     protected JComponent initEditor() {
         if (editor == null) {
             editor = FRGUIPaneFactory.createBorderLayout_S_Pane();
             editor.add(textField = new UITextField(5), BorderLayout.CENTER);
             btn = new LimpidButton(StringUtils.EMPTY, this.getIconPath(), toData().isVisible() ? FULL_OPACITY : HALF_OPACITY);
             btn.setPreferredSize(new Dimension(21, 21));
             editor.add(btn, BorderLayout.EAST);
             textField.setOpaque(false);
             editor.setBackground(Color.WHITE);
         }
         return editor;
     }

     @Override
     protected String getIconName() {
         return "date_16.png";
     }

     protected void makeVisible(boolean visible) {
         btn.makeVisible(visible);
     }

     /**
      * 获取当前XCreator的一个封装父容器
      *
      * @param widgetName 当前组件名
      * @return 封装的父容器
      * @date 2014-11-25-下午4:47:23
      */
     protected XLayoutContainer getCreatorWrapper(String widgetName) {
         return new XWScaleLayout();
     }

     /**
      * 将当前对象添加到父容器中
      *
      * @param parentPanel 父容器组件
      * @date 2014-11-25-下午4:57:55
      */
     protected void addToWrapper(XLayoutContainer parentPanel, int width, int minHeight) {
         this.setSize(width, minHeight);
         parentPanel.add(this);
     }

     /**
      * 此控件在自适应布局要保持原样高度
      *
      * @return 是则返回true
      */
     @Override
     public boolean shouldScaleCreator() {
         return true;
     }

     /**
      * data属性改变触发其他操作
      */
     public void firePropertyChange() {
         initFieldText();
     }
 }