 /*
  * Copyright (C), 2018-2021
  * Project: starter
  * FileName: ShowDateFormulaEditor
  * Author:   Louis
  * Date:     2021/11/29 12:01
  */
 package com.fr.plugin.hrjf.editors;

 import com.fr.base.BaseFormula;
 import com.fr.design.dialog.DialogActionAdapter;
 import com.fr.design.editor.editor.Editor;
 import com.fr.design.formula.FormulaFactory;
 import com.fr.design.formula.UIFormula;
 import com.fr.design.gui.itextfield.UITextField;
 import com.fr.design.layout.FRGUIPaneFactory;

 import javax.swing.*;
 import javax.swing.event.DocumentListener;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;

 /**
  * <Function Description><br>
  * <ShowDateFormulaEditor>
  *
  * @author fr.open
  * @since 1.0.0
  */
 public class ShowDateFormulaEditor extends Editor<BaseFormula> {
     private BaseFormula formula;
     private UITextField currentTextField;
     private ShowDateFormulaEditor.ShowPaneListener listener;

     public ShowDateFormulaEditor() {
         this("");
     }

     public ShowDateFormulaEditor(String var1) {
         this(var1, (BaseFormula) null);
     }

     public ShowDateFormulaEditor(String var1, BaseFormula var2) {
         this.formula = BaseFormula.createFormulaBuilder().build();
         this.listener = new ShowDateFormulaEditor.ShowPaneListener();
         if (var2 != null) {
             this.formula = var2;
         }

         this.setLayout(FRGUIPaneFactory.createBorderLayout());
//         JPanel var3 = FRGUIPaneFactory.createBorderLayout_S_Pane();
         this.currentTextField = new UITextField();
         this.currentTextField.setText(this.formula.getContent());
//         var3.add(this.currentTextField, "Center");
         this.currentTextField.setEditable(false);
         this.currentTextField.addMouseListener(this.listener);
//         this.add(var3, "Center");
         this.add(this.currentTextField, "Center");
         this.setName(var1);
     }

     public void setColumns(int var1) {
         this.currentTextField.setColumns(var1);
     }

     public void selected() {
         this.showFormulaPane();
     }

     public void setEnabled(boolean var1) {
         super.setEnabled(var1);
         this.currentTextField.setEnabled(var1);
     }

     protected void showFormulaPane() {
         final UIFormula var1 = FormulaFactory.createFormulaPaneWhenReserveFormula();
         var1.populate(this.formula);
         var1.showLargeWindow(SwingUtilities.getWindowAncestor(this), new DialogActionAdapter() {
             public void doOk() {
                 ShowDateFormulaEditor.this.formula = var1.update();
                 ShowDateFormulaEditor.this.setValue(ShowDateFormulaEditor.this.formula);
                 ShowDateFormulaEditor.this.fireStateChanged();
             }
         }).setVisible(true);
     }

     public BaseFormula getFormula() {
         return this.formula;
     }

     public UITextField getUITextField() {
         return this.currentTextField;
     }

     public BaseFormula getValue() {
         return this.formula != null && "=".equals(this.formula.getContent()) ? null : this.formula;
     }

     public void setValue(BaseFormula var1) {
         if (var1 == null) {
             var1 = BaseFormula.createFormulaBuilder().build();
         }

         this.formula = var1;
         this.currentTextField.setText(var1.toString());
     }

     public void addDocumentListener(DocumentListener var1) {
         this.currentTextField.getDocument().addDocumentListener(var1);
     }

     public String getIconName() {
         return "type_formula";
     }

     public boolean accept(Object var1) {
         return var1 instanceof BaseFormula;
     }

     public void reset() {
         this.currentTextField.setText("=");
         this.formula = BaseFormula.createFormulaBuilder().build();
     }

     public void clearData() {
         this.reset();
     }

     public void enableEditor(boolean var1) {
         this.setEnabled(var1);
         this.currentTextField.setEnabled(var1);
         if (!var1) {
             this.currentTextField.removeMouseListener(this.listener);
         } else {
             int var2 = this.currentTextField.getMouseListeners().length;

             for (int var3 = 0; var3 < var2; ++var3) {
                 this.currentTextField.removeMouseListener(this.listener);
             }

             this.currentTextField.addMouseListener(this.listener);
         }

     }

     private class ShowPaneListener extends MouseAdapter {
         private ShowPaneListener() {
         }

         public void mousePressed(MouseEvent var1) {
             if (ShowDateFormulaEditor.this.currentTextField.isEnabled()) {
                 ShowDateFormulaEditor.this.showFormulaPane();
             }

         }
     }
 }