 /*
  * Copyright (C), 2018-2021
  * Project: starter
  * FileName: ReturnFormatPane
  * Author:   Louis
  * Date:     2021/11/24 16:47
  */
 package com.fr.plugin.hrjf.pane;

 import com.fanruan.api.design.DesignKit;
 import com.fanruan.api.util.StringKit;
 import com.fr.design.designer.properties.items.Item;
 import com.fr.design.gui.ibutton.UIButtonGroup;
 import com.fr.design.gui.icombobox.UIComboBox;
 import com.fr.design.layout.FRGUIPaneFactory;
 import com.fr.general.ComparatorUtils;
 import com.fr.plugin.hrjf.items.DateFormatItems;
 import com.fr.plugin.hrjf.widget.VueDateEditor;

 import javax.swing.*;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import java.awt.*;

 import static com.fr.design.layout.FRGUIPaneFactory.createBorderLayout;

 /**
  * <Function Description><br>
  * <ReturnFormatPane>
  *
  * @author fr.open
  * @since 1.0.0
  */
 public class DateFormatPane extends JPanel {
     private CardLayout cardLayout;
     private JPanel customPane;
     private String[] tabTitles;
     private UIComboBox currentFormatComboBox;
     private UIComboBox dateFormatComboBox;
     private UIComboBox timeFormatComboBox;
     private UIButtonGroup<String> formatHeadGroup;

     public DateFormatPane() {
         this.initComponents();
     }

     private void initComponents() {
         this.setLayout(createBorderLayout());
         this.dateFormatComboBox = initUIComboBox(DateFormatItems.DATE_ITEMS);
         this.dateFormatComboBox.setSelectedIndex(2);
         this.dateFormatComboBox.addActionListener(e -> this.firePropertyChange("dateFormatValue", null, this.update()));
         this.timeFormatComboBox = initUIComboBox(DateFormatItems.TIME_ITEMS);
         this.timeFormatComboBox.setSelectedIndex(0);
         this.timeFormatComboBox.addActionListener(e -> this.firePropertyChange("dateFormatValue", null, this.update()));
         this.cardLayout = new CardLayout();
         this.customPane = new JPanel(cardLayout);
         JPanel dateFormatPane = createFormatPane(dateFormatComboBox);
         JPanel timeFormatPane = createFormatPane(timeFormatComboBox);
         customPane.add(dateFormatPane, DesignKit.i18nText("Plugin-hrjf-Date_Type_Date"));
         customPane.add(timeFormatPane, DesignKit.i18nText("Plugin-hrjf-Date_Type_DateTime"));
         this.tabTitles = new String[]{DesignKit.i18nText("Plugin-hrjf-Date_Type_Date"), DesignKit.i18nText("Plugin-hrjf-Date_Type_DateTime")};
         this.formatHeadGroup = new UIButtonGroup<>(new String[]{DesignKit.i18nText("Plugin-hrjf-Date_Type_Date"), DesignKit.i18nText("Plugin-hrjf-Date_Type_DateTime")});
         this.formatHeadGroup.addChangeListener(new ChangeListener() {
             @Override
             public void stateChanged(ChangeEvent e) {
                 int newSelectedIndex = formatHeadGroup.getSelectedIndex();
                 cardLayout.show(customPane, tabTitles[newSelectedIndex]);
                 if (newSelectedIndex == 0) {
                     currentFormatComboBox = dateFormatComboBox;
                 } else {
                     currentFormatComboBox = timeFormatComboBox;
                 }
             }
         });
         this.add(formatHeadGroup, BorderLayout.NORTH);
         this.add(customPane, BorderLayout.CENTER);
     }

     private JPanel createFormatPane(UIComboBox formatComboBox) {
         JPanel jPanel = FRGUIPaneFactory.createBorderLayout_S_Pane();
         jPanel.add(formatComboBox, BorderLayout.CENTER);
         return jPanel;
     }

     private UIComboBox initUIComboBox(Item[] items) {
         DefaultComboBoxModel model = new DefaultComboBoxModel();
         for (Item item : items) {
             model.addElement(item);
         }
         return new UIComboBox(model);
     }

     public void populate(String dateFormat) {
         if (StringKit.equals(dateFormat, DateFormatItems.YEAR)) {
             this.populate(0, 0);
         } else if (StringKit.equals(dateFormat, DateFormatItems.MONTH)) {
             this.populate(0, 1);
         } else if (StringKit.equals(dateFormat, DateFormatItems.DATE)) {
             this.populate(0, 2);
         } else if (StringKit.equals(dateFormat, DateFormatItems.DATES)) {
             this.populate(0, 3);
         } else if (StringKit.equals(dateFormat, DateFormatItems.WEEK)) {
             this.populate(0, 4);
         } else if (StringKit.equals(dateFormat, DateFormatItems.DATERANGE)) {
             this.populate(0, 5);
         } else if (StringKit.equals(dateFormat, DateFormatItems.DATERANGEWEEK)) {
             this.populate(0, 6);
         } else if (StringKit.equals(dateFormat, DateFormatItems.DATERANGEMONTH)) {
             this.populate(0, 7);
         } else if (StringKit.equals(dateFormat, DateFormatItems.DATETIME)) {
             this.populate(1, 0);
         } else if (StringKit.equals(dateFormat, DateFormatItems.DATETIMERANGE)) {
             this.populate(1, 1);
         } else {
             this.populate(0, 2);
         }
     }

     public void populate(int formatHead, int formatIndex) {
         this.formatHeadGroup.setSelectedIndex(formatHead);
         if (ComparatorUtils.equals(formatHead, 0)) {
             this.cardLayout.show(this.customPane, this.tabTitles[formatHead]);
             this.currentFormatComboBox = this.dateFormatComboBox;
             this.dateFormatComboBox.setSelectedIndex(formatIndex);
             this.timeFormatComboBox.setSelectedIndex(0);
         } else if (ComparatorUtils.equals(formatHead, 1)) {
             this.cardLayout.show(this.customPane, this.tabTitles[formatHead]);
             this.currentFormatComboBox = this.timeFormatComboBox;
             this.dateFormatComboBox.setSelectedIndex(0);
             this.timeFormatComboBox.setSelectedIndex(formatIndex);
         }
     }

     public String update() {
         if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 0)) {
             return DateFormatItems.YEAR;
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 1)) {
             return DateFormatItems.MONTH;
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 2)) {
             return DateFormatItems.DATE;
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 3)) {
             return DateFormatItems.DATES;
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 4)) {
             return DateFormatItems.WEEK;
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 5)) {
             return DateFormatItems.DATERANGE;
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 6)) {
             return DateFormatItems.DATERANGEWEEK;
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 7)) {
             return DateFormatItems.DATERANGEMONTH;
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 1) && ComparatorUtils.equals(this.timeFormatComboBox.getSelectedIndex(), 0)) {
             return DateFormatItems.DATETIME;
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 1) && ComparatorUtils.equals(this.timeFormatComboBox.getSelectedIndex(), 1)) {
             return DateFormatItems.DATETIMERANGE;
         } else {
             return DateFormatItems.DATE;
         }
     }

     public void update(VueDateEditor dateEditor) {
         if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 0)) {
             dateEditor.setDateFormat(DateFormatItems.YEAR);
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 1)) {
             dateEditor.setDateFormat(DateFormatItems.MONTH);
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 2)) {
             dateEditor.setDateFormat(DateFormatItems.DATE);
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 3)) {
             dateEditor.setDateFormat(DateFormatItems.DATES);
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 4)) {
             dateEditor.setDateFormat(DateFormatItems.WEEK);
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 5)) {
             dateEditor.setDateFormat(DateFormatItems.DATERANGE);
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 6)) {
             dateEditor.setDateFormat(DateFormatItems.DATERANGEWEEK);
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 0) && ComparatorUtils.equals(this.dateFormatComboBox.getSelectedIndex(), 7)) {
             dateEditor.setDateFormat(DateFormatItems.DATERANGEMONTH);
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 1) && ComparatorUtils.equals(this.timeFormatComboBox.getSelectedIndex(), 0)) {
             dateEditor.setDateFormat(DateFormatItems.DATETIME);
         } else if (ComparatorUtils.equals(this.formatHeadGroup.getSelectedIndex(), 1) && ComparatorUtils.equals(this.timeFormatComboBox.getSelectedIndex(), 1)) {
             dateEditor.setDateFormat(DateFormatItems.DATETIMERANGE);
         } else {
             dateEditor.setDateFormat(DateFormatItems.DATE);
         }
     }
 }