 /*
  * Copyright (C), 2018-2021
  * Project: starter
  * FileName: ShowDatePane
  * Author:   Louis
  * Date:     2021/11/28 23:22
  */
 package com.fr.plugin.hrjf.pane;

 import com.fr.base.BaseFormula;
 import com.fr.design.dialog.DialogActionAdapter;
 import com.fr.design.formula.FormulaFactory;
 import com.fr.design.formula.UIFormula;
 import com.fr.design.gui.itextfield.UITextField;
 import com.fr.design.i18n.Toolkit;
 import com.fr.design.layout.FRGUIPaneFactory;

 import javax.swing.*;
 import javax.swing.event.DocumentListener;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;

 /**
  * <Function Description><br>
  * <ShowDatePane>
  *
  * @author fr.open
  * @since 1.0.0
  */
 public class ShowDatePane extends JPanel {
     private final UITextField currentTextField;
     private BaseFormula formula;
     private ShowDatePane.ShowPaneListener listener;

     public ShowDatePane() {
         this.formula = BaseFormula.createFormulaBuilder().build();
         this.listener = new ShowDatePane.ShowPaneListener();
         this.setLayout(FRGUIPaneFactory.createBorderLayout());
         this.currentTextField = new UITextField();
         this.currentTextField.setText(this.formula.getContent());
         this.currentTextField.setEditable(false);
         this.currentTextField.addMouseListener(this.listener);
         this.add(this.currentTextField, "Center");
         this.setName(Toolkit.i18nText("Fine-Design_Report_Parameter_Formula"));
     }

     protected void showFormulaPane() {
         final UIFormula reserveFormula = FormulaFactory.createFormulaPaneWhenReserveFormula();
         reserveFormula.populate(this.formula);
         reserveFormula.showLargeWindow(SwingUtilities.getWindowAncestor(this), new DialogActionAdapter() {
             public void doOk() {
                 ShowDatePane.this.formula = reserveFormula.update();
             }
         }).setVisible(true);
     }

     public BaseFormula update() {
         return this.formula != null && "=".equals(this.formula.getContent()) ? null : this.formula;
     }

     public void populate(BaseFormula value) {
         if (value == null) {
             value = BaseFormula.createFormulaBuilder().build();
         }
         this.formula = value;
         this.currentTextField.setText(value.toString());
     }

     public BaseFormula getFormula() {
         return this.formula;
     }

     public UITextField getUITextField() {
         return this.currentTextField;
     }

     public void addDocumentListener(DocumentListener var1) {
         this.currentTextField.getDocument().addDocumentListener(var1);
     }

     private class ShowPaneListener extends MouseAdapter {
         private ShowPaneListener() {
         }

         public void mousePressed(MouseEvent var1) {
             if (ShowDatePane.this.currentTextField.isEnabled()) {
                 ShowDatePane.this.showFormulaPane();
             }

         }
     }
 }