 /*
  * Copyright (C), 2018-2021
  * Project: starter
  * FileName: VueDateEditorPane
  * Author:   Louis
  * Date:     2021/11/8 16:38
  */
 package com.fr.plugin.hrjf.pane;

 import com.fanruan.api.design.ui.component.UITextArea;
 import com.fr.design.designer.IntervalConstants;
 import com.fr.design.designer.properties.items.Item;
 import com.fr.design.gui.ibutton.UIButtonGroup;
 import com.fr.design.gui.icombobox.UIComboBox;
 import com.fr.design.gui.ilable.UILabel;
 import com.fr.design.gui.itextfield.UITextField;
 import com.fr.design.i18n.Toolkit;
 import com.fr.design.layout.TableLayout;
 import com.fr.design.layout.TableLayoutHelper;
 import com.fr.design.widget.ui.DirectWriteEditorDefinePane;
 import com.fr.plugin.hrjf.items.FirstDayOfWeekItems;
 import com.fr.plugin.hrjf.widget.VueDateEditor;

 import javax.swing.*;
 import java.awt.*;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;

 /**
  * <Function Description><br>
  * <单元格日期控件设置界面类VueDateEditorPane>
  *
  * @author fr.open
  * @since 1.0.0
  */
 public class VueDateEditorPane extends DirectWriteEditorDefinePane<VueDateEditor> {
     private static final int CONTENT_PANE_COLUMNS = 25;

     private DateFormatPane dateFormatPane;
     private ReturnFormatPane showDatePane;
     private ReturnFormatPane returnFormatPane;
     private UIComboBox firstDayOfWeekComboBox;
     private UIButtonGroup<String> returnTypeComboBox;
     private UITextField dateSeparatorTextField;
     private UITextArea configurationItemTextArea;

     public VueDateEditorPane() {
     }

     @Override
     protected String title4PopupWindow() {
         return "VueDate";
     }

     @Override
     protected JPanel setSecondContentPane() {
         // 类型/格式
         UILabel formatLabel = new UILabel(Toolkit.i18nText("Plugin-hrjf-Date_Format"));
         formatLabel.setVerticalAlignment(SwingConstants.TOP);
         this.dateFormatPane = new DateFormatPane();
         this.dateFormatPane.addPropertyChangeListener("dateFormatValue", new PropertyChangeListener() {
             @Override
             public void propertyChange(PropertyChangeEvent evt) {
                 VueDateEditorPane.this.showDatePane.populateShowDate(evt.getNewValue());
             }
         });
         // 显示日期格式
         UILabel showDateLabel = new UILabel(Toolkit.i18nText("Plugin-hrjf-Design_Form_Show_Date"));
         showDateLabel.setVerticalAlignment(SwingConstants.TOP);
         this.showDatePane = new ReturnFormatPane();
         // 返回格式
         UILabel returnFormatLabel = new UILabel(Toolkit.i18nText("Plugin-hrjf-Design_Form_Return_Format"));
         returnFormatLabel.setVerticalAlignment(SwingConstants.TOP);
         this.returnFormatPane = new ReturnFormatPane();
         // 周起始日
         UILabel firstDayOfWeekLabel = new UILabel(Toolkit.i18nText("Plugin-hrjf-Design_Form_Week_Start_Date"));
         firstDayOfWeekLabel.setVerticalAlignment(SwingConstants.TOP);
         this.firstDayOfWeekComboBox = FirstDayOfWeekItems.getUIComboBox();
         // 返回类型
         UILabel returnTypeLabel = new UILabel(Toolkit.i18nText("Plugin-hrjf-Design_Form_Return_Type"));
         returnTypeLabel.setVerticalAlignment(SwingConstants.TOP);
         this.returnTypeComboBox = new UIButtonGroup<>(new String[]{Toolkit.i18nText("Fine-Design_Basic_Date"), Toolkit.i18nText("Fine-Design_Basic_String")});
         // 数组拼接符
         UILabel dateSeparatorLabel = new UILabel(Toolkit.i18nText("Plugin-hrjf-Design_Form_Date_Separator"));
         dateSeparatorLabel.setVerticalAlignment(SwingConstants.TOP);
         this.dateSeparatorTextField = new UITextField();
         // 配置项
         UILabel configurationItemLabel = new UILabel(Toolkit.i18nText("Plugin-hrjf-Design_Form_Configuration_Item"));
         configurationItemLabel.setVerticalAlignment(SwingConstants.TOP);
         this.configurationItemTextArea = new UITextArea(5, CONTENT_PANE_COLUMNS);

         double f = TableLayout.FILL;
         double p = TableLayout.PREFERRED;
         Component[][] components = new Component[][]{
                 new Component[]{formatLabel, this.dateFormatPane},
                 new Component[]{showDateLabel, this.showDatePane},
                 new Component[]{returnFormatLabel, this.returnFormatPane},
                 new Component[]{firstDayOfWeekLabel, this.firstDayOfWeekComboBox},
                 new Component[]{returnTypeLabel, this.returnTypeComboBox},
                 new Component[]{dateSeparatorLabel, this.dateSeparatorTextField},
                 new Component[]{dateSeparatorLabel, this.dateSeparatorTextField},
                 new Component[]{configurationItemLabel, this.configurationItemTextArea},
                 new Component[]{this.waterMarkDictPane, null}
         };
         double[] rowSize = {p, p, p, p, p, p, p, p, p, p, p};
         double[] columnSize = {p, f};
         int[][] rowCount = {{1, 3}, {1, 1}, {1, 1}, {1, 1}, {1, 1}, {1, 1}, {1, 1}, {1, 1}, {1, 1}};
         JPanel panel = TableLayoutHelper.createGapTableLayoutPane(components, rowSize, columnSize, rowCount, IntervalConstants.INTERVAL_L2, IntervalConstants.INTERVAL_L1);
         return panel;
     }

     @Override
     protected void populateSubDirectWriteEditorBean(VueDateEditor dateEditor) {
         this.dateFormatPane.populate(dateEditor.getDateFormat());
         this.showDatePane.populateShowDate(dateEditor);
         this.returnFormatPane.populateReturnFormat(dateEditor);
         this.firstDayOfWeekComboBox.setSelectedItem(new Item("", dateEditor.getFirstDayOfWeek()));
         this.returnTypeComboBox.setSelectedIndex(dateEditor.getReturnTypeInt());
         this.dateSeparatorTextField.setText(dateEditor.getDateSeparator());
         this.configurationItemTextArea.setText(dateEditor.getConfigurationItem());
     }

     @Override
     protected VueDateEditor updateSubDirectWriteEditorBean() {
         VueDateEditor dateEditor = new VueDateEditor();
         this.dateFormatPane.update(dateEditor);
         this.showDatePane.update(dateEditor, true);
         this.returnFormatPane.update(dateEditor, false);
         dateEditor.setFirstDayOfWeek(this.firstDayOfWeekComboBox.getSelectedItem());
         dateEditor.setReturnType(this.returnTypeComboBox.getSelectedIndex());
         dateEditor.setDateSeparator(this.dateSeparatorTextField.getText());
         dateEditor.setConfigurationItem(this.configurationItemTextArea.getText());
         return dateEditor;
     }
 }