 /*
  * Copyright (C), 2018-2021
  * Project: starter
  * FileName: VueDateEditorWidget
  * Author:   Louis
  * Date:     2021/11/5 16:32
  */
 package com.fr.plugin.hrjf.widget;

 import com.fanruan.api.log.LogKit;
 import com.fanruan.api.util.StringKit;
 import com.fr.base.BaseFormula;
 import com.fr.base.ParameterMapNameSpace;
 import com.fr.base.Utils;
 import com.fr.data.core.FormatField;
 import com.fr.design.designer.properties.items.Item;
 import com.fr.form.FormUtils;
 import com.fr.form.ui.DataControl;
 import com.fr.form.ui.DirectWriteEditor;
 import com.fr.form.ui.Widget;
 import com.fr.form.ui.WidgetValue;
 import com.fr.form.ui.concept.data.ValueInitializer;
 import com.fr.general.ComparatorUtils;
 import com.fr.general.DateUtils;
 import com.fr.json.JSONArray;
 import com.fr.json.JSONException;
 import com.fr.json.JSONObject;
 import com.fr.plugin.hrjf.editors.DateTypeEditor;
 import com.fr.plugin.hrjf.editors.ReturnTypeEditor;
 import com.fr.plugin.hrjf.items.FirstDayOfWeekItems;
 import com.fr.script.Calculator;
 import com.fr.stable.ArrayUtils;
 import com.fr.stable.CommonUtils;
 import com.fr.stable.StringUtils;
 import com.fr.stable.UtilEvalError;
 import com.fr.stable.core.NodeVisitor;
 import com.fr.stable.script.CalculatorProvider;
 import com.fr.stable.web.Repository;
 import com.fr.stable.web.SessionProvider;
 import com.fr.stable.xml.XMLPrintWriter;
 import com.fr.stable.xml.XMLableReader;
 import com.fr.web.utils.WebUtils;

 import javax.servlet.http.HttpServletRequest;
 import java.text.SimpleDateFormat;
 import java.util.Collections;
 import java.util.Date;
 import java.util.HashSet;

 import static com.fr.plugin.hrjf.creator.XVueDateEditor.*;

 /**
  * <Function Description><br>
  * <VueDateEditor>
  *
  * @author fr.open
  * @since 1.0.0
  */
 public class VueDateEditor extends DirectWriteEditor implements DataControl {
     private static final long serialVersionUID = 1406480833692359017L;
     public static String oldDateTimeWidgetTag = "com.fr.report.web.ui.DateTimeEditor";
     public static String oldDateTimeFormat = "yyyy-MM-dd HH:mm";
     public static final String SHOW_DATE_FM = "showDateFM";
     public static final String RETURN_FORMAT_FM = "returnFormatFM";
     private String startDate;
     private String endDate;
     private BaseFormula startDateFM;
     private BaseFormula endDateFM;
     private String formatText = "yyyy-MM-dd";
     private boolean returnDate = false;
     private ValueInitializer widgetValue = new WidgetValue();
     // 日期类型和格式
     private String dateFormat = DateTypeEditor.DATE;
     // 显示日期格式
     private String showDate;
     private BaseFormula showDateFM;
     // 返回格式
     private String returnFormat;
     private BaseFormula returnFormatFM;
     // 周起始日
     private int firstDayOfWeek = FirstDayOfWeekItems.SUNDAY;
     // 返回类型
     private String returnType = ReturnTypeEditor.STRING;
     // 数组拼接符
     private String dateSeparator = ",";
     // 配置项
     private String configurationItem = StringKit.EMPTY;

     public VueDateEditor() {
     }

     @Override
     public String getXType() {
         return "vue_datetime";
     }

     @Override
     public String getFormatText() {
         return this.formatText;
     }

     public void setFormatText(String formatText) {
         this.formatText = formatText;
     }

     @Override
     public int[] getValueType() {
         return new int[]{4, 3, 2};
     }

     @Override
     public ValueInitializer getWidgetValue() {
         return this.widgetValue;
     }

     @Override
     public void setWidgetValue(ValueInitializer valueInitializer) {
         this.widgetValue = valueInitializer;
     }

     @Override
     public String[] dependence(CalculatorProvider var1) {
         HashSet var2 = new HashSet();
         if (this.widgetValue != null) {
             Collections.addAll(var2, this.widgetValue.dependence(var1));
         }

         Collections.addAll(var2, FormUtils.getDependence(this.getStartDate(), var1));
         Collections.addAll(var2, FormUtils.getDependence(this.getEndDate(), var1));
         return (String[]) var2.toArray(new String[var2.size()]);
     }

     public Object getStartDateValue(Calculator var1) throws Exception {
         if (this.startDateFM != null) {
             return var1.eval(this.startDateFM);
         } else {
             return this.startDate != null ? DateUtils.string2Date(this.startDate, true) : null;
         }
     }

     public Object getEndDateValue(Calculator var1) throws Exception {
         if (this.endDateFM != null) {
             return var1.eval(this.endDateFM);
         } else {
             return this.endDate != null ? DateUtils.string2Date(this.endDate, true) : null;
         }
     }

     public Object getStartDate() {
         if (this.startDateFM != null) {
             return this.startDateFM;
         } else {
             return this.startDate != null ? DateUtils.string2Date(this.startDate, true) : null;
         }
     }

     public void setStartDate(Object var1) {
         if (var1 instanceof BaseFormula) {
             this.startDateFM = (BaseFormula) var1;
             this.startDate = null;
         } else if (var1 instanceof Date) {
             this.startDateFM = null;
             this.startDate = DateUtils.getDate2Str("MM/dd/yyyy", (Date) var1);
         } else {
             this.startDateFM = null;
             this.startDate = null;
         }

     }

     public Object getEndDate() {
         if (this.endDateFM != null) {
             return this.endDateFM;
         } else {
             return this.endDate != null ? DateUtils.string2Date(this.endDate, true) : null;
         }
     }

     public void setEndDate(Object var1) {
         if (var1 instanceof BaseFormula) {
             this.endDateFM = (BaseFormula) var1;
             this.endDate = null;
         } else if (var1 instanceof Date) {
             this.endDateFM = null;
             this.endDate = DateUtils.getDate2Str("MM/dd/yyyy", (Date) var1);
         } else {
             this.endDateFM = null;
             this.endDate = null;
         }

     }

     public String getStartText() {
         return this.startDate;
     }

     public void setStartText(String var1) {
         this.startDate = var1;
     }

     public String getEndText() {
         return this.endDate;
     }

     public void setEndText(String var1) {
         this.endDate = var1;
     }

     public BaseFormula getStartDateFM() {
         return this.startDateFM;
     }

     public void setStartDateFM(BaseFormula var1) {
         this.startDateFM = var1;
     }

     public BaseFormula getEndDateFM() {
         return this.endDateFM;
     }

     public void setEndDateFM(BaseFormula var1) {
         this.endDateFM = var1;
     }

     public boolean isReturnDate() {
         return this.returnDate;
     }

     public void setReturnDate(boolean var1) {
         this.returnDate = var1;
     }

     @Override
     public void createValueResult(CalculatorProvider var1, JSONObject var2) {
         if (this.widgetValue != null) {
             var1.setAttribute(Widget.NAME, this.getWidgetName().toUpperCase());
             Object var3 = this.getWidgetValue().executeResult(var1);
             if (!this.returnDate && var3 instanceof Date && this.formatText != null) {
                 var3 = (new SimpleDateFormat(this.formatText)).format((Date) var3);
             }

             var2.put(this.widgetName.toUpperCase(), var3 == null ? "" : var3);
         }
     }

     @Override
     public String getDataBindDefaultValue(CalculatorProvider var1) {
         if (this.widgetValue == null) {
             this.setWidgetValue(new WidgetValue());
         }

         Object var2 = this.getWidgetValue().executeResult(var1);
         if (var2 == null) {
             return null;
         } else {
             return var2 instanceof Date && this.formatText != null ? (new SimpleDateFormat(this.formatText)).format((Date) var2) : Utils.objectToString(var2);
         }
     }

     @Override
     public JSONObject createJSONConfig(Repository repository, Calculator calculator, NodeVisitor nodeVisitor) throws JSONException {
         JSONObject jsonObject = super.createJSONConfig(repository, calculator, nodeVisitor);
         Object var5 = jsonObject.get("value");
         if (var5 == null) {
             jsonObject.remove("value");
         } else if (var5 instanceof Date) {
             jsonObject.put("value", (new JSONObject()).put("date_milliseconds", ((Date) var5).getTime()));
         }

         if (StringUtils.isNotEmpty(this.formatText)) {
             jsonObject.put("format", this.formatText);
             if (!ArrayUtils.contains(FormatField.getInstance().getDateFormatArray(), this.formatText)) {
                 jsonObject.put("customFormat", true);
             }
         }

         if (this.startDate != null) {
             jsonObject.put("startDate", this.value2Config(this.startDate, calculator));
         } else if (this.startDateFM != null) {
             try {
                 jsonObject.put("startDate", this.value2Config(calculator.evalValue(this.startDateFM.getContent()), calculator));
             } catch (UtilEvalError var7) {
                 LogKit.error(var7.getMessage(), var7);
             }
         }

         if (this.endDate != null) {
             jsonObject.put("endDate", this.value2Config(this.endDate, calculator));
         } else if (this.endDateFM != null) {
             try {
                 jsonObject.put("endDate", this.value2Config(calculator.evalValue(this.endDateFM.getContent()), calculator));
             } catch (UtilEvalError var6) {
                 LogKit.error(var6.getMessage(), var6);
             }
         }

         if (this.returnDate) {
             jsonObject.put("returnDate", true);
         }

         if (StringKit.isNotBlank(this.getDateFormat())) {
             jsonObject.put(DATE_FORMAT, this.getDateFormat());
         }

         try {
             if (StringKit.isNotBlank(this.getShowDate())) {
                 jsonObject.put(SHOW_DATE, this.getShowDate());
             }
             if (!CommonUtils.isNull(this.getShowDateFM())) {
                 jsonObject.put(SHOW_DATE, calculator.evalValue(this.getShowDateFM()));
             }
             if (StringKit.isNotBlank(this.getReturnFormat())) {
                 jsonObject.put(RETURN_FORMAT, this.getReturnFormat());
             }
             if (!CommonUtils.isNull(this.getReturnFormatFM())) {
                 jsonObject.put(RETURN_FORMAT, calculator.evalValue(this.getReturnFormatFM()));
             }
         } catch (UtilEvalError e) {
             LogKit.error(e.getMessage(), e);
         }
         jsonObject.put(FIRST_DAY_OF_WEEK, this.getFirstDayOfWeek());

         if (StringKit.isNotBlank(this.getReturnType())) {
             jsonObject.put(RETURN_TYPE, this.getReturnType());
         }

         if (StringKit.isNotBlank(this.getDateSeparator())) {
             jsonObject.put(DATE_SEPARATOR, this.getDateSeparator());
         }

         if (StringKit.isNotBlank(this.getConfigurationItem())) {
             jsonObject.put(CONFIGURATION_ITEM, this.getConfigurationItem());
         }

         String[] var9 = this.dependence(calculator);
         if (!ArrayUtils.isEmpty(var9)) {
             jsonObject.put("dependence", var9);
         }

         return jsonObject;
     }

     @Override
     public JSONArray createJSONData(SessionProvider var1, Calculator var2, HttpServletRequest var3) throws Exception {
         JSONArray var4 = super.createJSONData(var1, var2, var3);
         ParameterMapNameSpace var5 = ParameterMapNameSpace.create(var1.getOriginalParameterMap());
         DependenceNameSpace var6 = new DependenceNameSpace(WebUtils.getHTTPRequestParameter(var3, "dependence"));
         var2.pushNameSpace(var5);
         var2.pushNameSpace(var6);
         JSONObject var7 = JSONObject.create();
         var7.put("startDate", this.value2Config(this.getStartDateValue(var2), var2));
         var7.put("endDate", this.value2Config(this.getEndDateValue(var2), var2));
         var4.put(var7);
         var2.removeNameSpace(var5);
         var2.removeNameSpace(var6);
         return var4;
     }

     @Override
     public Object value2Config(Object var1, CalculatorProvider var2) {
         String var3;
         if (var1 instanceof Date) {
             var3 = (new SimpleDateFormat(this.formatText)).format((Date) var1);
         } else if (var1 == null) {
             var3 = "";
         } else {
             String var4 = Utils.objectToString(var1);

             try {
                 Date var5 = DateUtils.string2Date(var4, false);
                 var3 = (new SimpleDateFormat(this.formatText)).format(var5);
             } catch (Exception var6) {
                 var3 = var1.toString();
             }
         }

         return var3;
     }

     @Override
     public String[] supportedEvents() {
         return new String[]{"afterinit", "afteredit", "stopedit"};
     }

     @Override
     public boolean equals(Object obj) {
         return obj instanceof VueDateEditor && super.equals(obj)
                 && ComparatorUtils.equals(this.startDate, ((VueDateEditor) obj).startDate)
                 && ComparatorUtils.equals(this.endDate, ((VueDateEditor) obj).endDate)
                 && this.returnDate == ((VueDateEditor) obj).returnDate;
     }

     @Override
     public void readXML(XMLableReader reader) {
         super.readXML(reader);
         if (reader.isChildNode()) {
             String tagName = reader.getTagName();
             if ("DateAttr".equals(tagName)) {
                 String var3 = null;
                 if ((var3 = reader.getAttrAsString("format", (String) null)) != null) {
                     this.setFormatText(var3);
                 }

                 if ((var3 = reader.getAttrAsString("start", (String) null)) != null) {
                     this.startDate = var3;
                 } else if ((var3 = reader.getAttrAsString("startdatefm", (String) null)) != null) {
                     this.startDateFM = BaseFormula.createFormulaBuilder().build(var3);
                 }

                 if ((var3 = reader.getAttrAsString("end", (String) null)) != null) {
                     this.endDate = var3;
                 } else if ((var3 = reader.getAttrAsString("enddatefm", (String) null)) != null) {
                     this.endDateFM = BaseFormula.createFormulaBuilder().build(var3);
                 }
                 this.returnDate = reader.getAttrAsBoolean("returnDate", false);
                 this.setShowDate(reader.getAttrAsString(SHOW_DATE, StringKit.EMPTY));
                 this.setShowDateFM(BaseFormula.createFormulaBuilder().build(reader.getAttrAsString(SHOW_DATE_FM, StringKit.EMPTY)));
                 this.setReturnFormat(reader.getAttrAsString(RETURN_FORMAT, StringKit.EMPTY));
                 this.setReturnFormatFM(BaseFormula.createFormulaBuilder().build(reader.getAttrAsString(RETURN_FORMAT_FM, StringKit.EMPTY)));
                 this.setFirstDayOfWeek(reader.getAttrAsInt(FIRST_DAY_OF_WEEK, FirstDayOfWeekItems.SUNDAY));
                 this.setReturnType(reader.getAttrAsString(RETURN_TYPE, ReturnTypeEditor.STRING));
                 this.setDateFormat(reader.getAttrAsString(DATE_FORMAT, DateTypeEditor.DATE));
                 this.setDateSeparator(reader.getAttrAsString(DATE_SEPARATOR, StringKit.EMPTY));
                 this.setConfigurationItem(reader.getAttrAsString(CONFIGURATION_ITEM, StringKit.EMPTY));
             } else if ("widgetValue".equals(tagName)) {
                 this.widgetValue = new WidgetValue();
                 reader.readXMLObject(this.widgetValue);
             }
         }
         if (ComparatorUtils.equals(reader.getAttrAsString("class", (String) null), oldDateTimeWidgetTag) && reader.getAttrAsString("format", (String) null) == null) {
             this.setFormatText(oldDateTimeFormat);
         }
     }

     @Override
     public void writeXML(XMLPrintWriter writer) {
         super.writeXML(writer);
         writer.startTAG("DateAttr");
         if (!ComparatorUtils.equals(this.getFormatText(), this.getDefaultFormatText())) {
             writer.attr("format", this.getFormatText());
         }

         if (StringUtils.isNotEmpty(this.startDate)) {
             writer.attr("start", this.startDate);
         } else if (this.startDateFM != null) {
             writer.attr("startdatefm", this.startDateFM.getContent());
         }

         if (StringUtils.isNotEmpty(this.endDate)) {
             writer.attr("end", this.endDate);
         } else if (this.endDateFM != null) {
             writer.attr("enddatefm", this.endDateFM.getContent());
         }

         if (this.returnDate) {
             writer.attr("returnDate", true);
         }

         if (StringKit.isNotBlank(this.getDateFormat())) {
             writer.attr(DATE_FORMAT, this.getDateFormat());
         }
         if (StringKit.isNotBlank(this.getShowDate())) {
             writer.attr(SHOW_DATE, this.getShowDate());
         }
         if (this.getShowDateFM() != null && StringKit.isNotBlank(this.getShowDateFM().getContent())) {
             writer.attr(SHOW_DATE_FM, this.getShowDateFM().getContent());
         }
         if (StringKit.isNotBlank(this.getReturnFormat())) {
             writer.attr(RETURN_FORMAT, this.getReturnFormat());
         }
         if (this.getReturnFormatFM() != null && StringKit.isNotBlank(this.getReturnFormatFM().getContent())) {
             writer.attr(RETURN_FORMAT_FM, this.getReturnFormatFM().getContent());
         }
         writer.attr(FIRST_DAY_OF_WEEK, this.getFirstDayOfWeek());
         if (StringKit.isNotBlank(this.getReturnType())) {
             writer.attr(RETURN_TYPE, this.getReturnType());
         }
         if (StringKit.isNotBlank(this.getDateSeparator())) {
             writer.attr(DATE_SEPARATOR, this.getDateSeparator());
         }
         if (StringKit.isNotBlank(this.getConfigurationItem())) {
             writer.attr(CONFIGURATION_ITEM, this.getConfigurationItem());
         }

         writer.end();
         if (this.widgetValue != null) {
             this.widgetValue.writeXML(writer);
         }
     }

     protected String getDefaultFormatText() {
         return "yyyy-MM-dd";
     }

     public String getShowDate() {
         return showDate;
     }

     public void setShowDate(String showDate) {
         this.showDate = showDate;
     }

     public BaseFormula getShowDateFM() {
         return showDateFM;
     }

     public void setShowDateFM(BaseFormula showDateFM) {
         this.showDateFM = showDateFM;
     }

     public int getFirstDayOfWeek() {
         return firstDayOfWeek;
     }

     public void setFirstDayOfWeek(Object firstDayOfWeek) {
         Item selectedItem = (Item) firstDayOfWeek;
         this.firstDayOfWeek = Integer.parseInt(String.valueOf(selectedItem.getValue()));
     }

     public void setFirstDayOfWeek(int firstDayOfWeek) {
         this.firstDayOfWeek = firstDayOfWeek;
     }

     public String getConfigurationItem() {
         return configurationItem;
     }

     public void setConfigurationItem(String configurationItem) {
         this.configurationItem = configurationItem;
     }

     public String getDateFormat() {
         return dateFormat;
     }

     public void setDateFormat(String dateFormat) {
         this.dateFormat = dateFormat;
     }

     public String getReturnFormat() {
         return returnFormat;
     }

     public void setReturnFormat(String returnFormat) {
         this.returnFormat = returnFormat;
     }

     public BaseFormula getReturnFormatFM() {
         return returnFormatFM;
     }

     public void setReturnFormatFM(BaseFormula returnFormatFM) {
         this.returnFormatFM = returnFormatFM;
     }

     public int getReturnTypeInt() {
         if (StringKit.equals(this.returnType, ReturnTypeEditor.STRING)) {
             return 0;
         } else if (StringKit.equals(this.returnType, ReturnTypeEditor.DATE)) {
             return 1;
         } else {
             return 0;
         }
     }

     public String getReturnType() {
         return returnType;
     }

     public void setReturnType(int returnType) {
         if (ComparatorUtils.equals(returnType, 0)) {
             this.returnType = ReturnTypeEditor.STRING;
         } else if (ComparatorUtils.equals(returnType, 1)) {
             this.returnType = ReturnTypeEditor.DATE;
         } else {
             this.returnType = ReturnTypeEditor.STRING;
         }
     }

     public void setReturnType(String returnType) {
         this.returnType = returnType;
     }

     public String getDateSeparator() {
         return dateSeparator;
     }

     public void setDateSeparator(String dateSeparator) {
         this.dateSeparator = dateSeparator;
     }
 }